==> netbeans_6.1.orig.tar.gz: netbeans-6.1/ide.kit/test/qa-functional/src/org/netbeans/test/editor/MultiviewEditorReflectionTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.test.editor;

import java.lang.reflect.Method;
import org.netbeans.junit.NbTestCase;
import org.openide.util.Lookup;
import org.openide.util.SharedClassObject;

/**
 * test for reflection used in multiview module that retrieves a setting value from editor.
 *
 * @author mkleint
 */
public class MultiviewEditorReflectionTest extends NbTestCase {

    /** Creates a new instance of MultiviewEditorReflectionTest */
    public MultiviewEditorReflectionTest(String name) {
        super(name);
    }

    public void testReflection() throws Exception {
            final ClassLoader loader = (ClassLoader)Lookup.getDefault().lookup(ClassLoader.class);
            Class settingsClass = Class.forName(
                    "org.netbeans.editor.Settings", false, loader); //NOI18N
            Class listenerClass = Class.forName(
                    "org.netbeans.editor.SettingsChangeListener", false, loader); //NOI18N
            Method addSettingsListener = settingsClass.getMethod(
                    "addSettingsChangeListener",new Class[ ] { listenerClass });//NOI18N
            Method removeSettingsListener = settingsClass.getMethod(
                    "removeSettingsChangeListener",new Class[ ] { listenerClass });//NOI18N

            Class editorBaseOption = Class.forName("org.netbeans.modules.editor.options.BaseOptions", true,
                    loader);
            SharedClassObject option = SharedClassObject.findObject(editorBaseOption);
            Method is = option.getClass().getMethod("isToolbarVisible", new Class[0]);
    }

}

==> netbeans_6.5.orig.tar.gz: netbeans-6.5/ide.kit/test/qa-functional/src/org/netbeans/test/editor/MultiviewEditorReflectionTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.test.editor;

import junit.framework.Test;
import org.netbeans.junit.NbModuleSuite;
import org.netbeans.junit.NbTestCase;
import org.openide.util.Lookup;
import org.openide.util.SharedClassObject;

/**
 * test for reflection used in multiview module that retrieves a setting value from editor.
 *
 * @author mkleint
 */
public class MultiviewEditorReflectionTest extends NbTestCase {

    public MultiviewEditorReflectionTest(String name) {
        super(name);
    }
    
    public static Test suite() {
        return NbModuleSuite.create(
            NbModuleSuite.createConfiguration(
                MultiviewEditorReflectionTest.class
            ).gui(false).clusters(".*").enableModules(".*")
        );
    }

    public void testReflection() throws Exception {
            ClassLoader loader = Lookup.getDefault().lookup(ClassLoader.class);
            Class settingsClass = Class.forName("org.netbeans.editor.Settings", false, loader);
            Class listenerClass = Class.forName("org.netbeans.editor.SettingsChangeListener", false, loader);
            settingsClass.getMethod("addSettingsChangeListener", listenerClass);
            settingsClass.getMethod("removeSettingsChangeListener", listenerClass);
            Class<?> editorBaseOption = Class.forName("org.netbeans.modules.editor.options.BaseOptions", true, loader);
            SharedClassObject.findObject(editorBaseOption.asSubclass(SharedClassObject.class), true);
            editorBaseOption.getMethod("isToolbarVisible");
    }

}
